Learn R Programming

sistec (version 0.2.0)

aria_desktop_build: Build ARIA desktop version

Description

Build the desktop version of ARIA automatically. You will need innosetup to build the executable. Only works in windows. See Details for more information.

Usage

aria_desktop_build(aria_folder = "", download_dependencies = TRUE)

Arguments

aria_folder

The folder you want to create the executable.

download_dependencies

Download all the dependencies: r-portable and packages needed to run the ARIA. Use FALSE if you already have the dependencies in the aria_folder.

Value

Create the setup to build ARIA desktop in your specified folder.

Details

To create the executable correctly, follow theses steps:

  • Build the sistec package (in Rstudio, you use ctrl + shift + b)

  • Create a folder

  • Use aria_desktop_build("your folder")

  • Install innosetup (if you don't have it installed yet)

  • Double click the .iss file created in your folder and run it.

Examples

Run this code
# NOT RUN {
aria_folder <- tempdir()
aria_desktop_build(aria_folder)
# }

Run the code above in your browser using DataLab